==> trilinos_12.14.1.orig.tar.gz: Trilinos-trilinos-release-12-14-1/packages/stk/stk_mesh/stk_mesh/baseImpl/ElementTopologyDeletions.hpp <==
#ifndef STK_ELEMENT_TOPOLOGY_DELETIONS_H
#define STK_ELEMENT_TOPOLOGY_DELETIONS_H

#include "stk_mesh/base/BulkData.hpp"
#include "stk_mesh/base/Entity.hpp"
#include "stk_mesh/base/MetaData.hpp"
#include "stk_mesh/base/Selector.hpp"
#include "stk_mesh/base/Types.hpp"

namespace stk
{
namespace mesh
{
namespace impl
{

struct RelationEntityToNode
{
    Entity entity;
    Entity node;
    ConnectivityOrdinal ordinal;
};

class ElementTopologyDeletions
{
public:
    ElementTopologyDeletions(stk::mesh::BulkData &bulkData, stk::topology topologyToDelete);
    void find_buckets_to_destroy_and_relations_to_sever();
    const std::vector<RelationEntityToNode> & get_relations_to_sever() const;
    const stk::mesh::BucketVector & get_buckets_to_delete() const;

private:
    stk::mesh::Selector get_all_other_element_topologies_selector(const stk::mesh::MetaData &meta, stk::topology topology);
    void append_upward_relations_to_sever(stk::mesh::Bucket &bucket);
private:
    stk::mesh::BulkData & bulk;
    stk::mesh::Selector topoSelector;
    stk::mesh::Selector selectsOtherElemTopologies;
    stk::mesh::BucketVector bucketsToDelete;
    std::vector<RelationEntityToNode> relationsToDestroy;
};

}
}
}

// Copyright (c) 2013, Sandia Corporation.
 // Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
 // the U.S. Government retains certain rights in this software.
 // 
 // Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are
 // met:
 // 
 //     * Redistributions of source code must retain the above copyright
 //       notice, this list of conditions and the following disclaimer.
 // 
 //     * Redistributions in binary form must reproduce the above
 //       copyright notice, this list of conditions and the following
 //       disclaimer in the documentation and/or other materials provided
 //       with the distribution.
 // 
 //     * Neither the name of Sandia Corporation nor the names of its
 //       contributors may be used to endorse or promote products derived
 //       from this software without specific prior written permission.
 // 
 // THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 // "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 // LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 // A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 // OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 // SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 // LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 // DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 // THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#endif

==> trilinos_13.2.0.orig.tar.gz: Trilinos-trilinos-release-13-2-0/packages/stk/stk_mesh/stk_mesh/baseImpl/ElementTopologyDeletions.hpp <==
#ifndef STK_ELEMENT_TOPOLOGY_DELETIONS_H
#define STK_ELEMENT_TOPOLOGY_DELETIONS_H

#include "stk_mesh/base/BulkData.hpp"
#include "stk_mesh/base/Entity.hpp"
#include "stk_mesh/base/MetaData.hpp"
#include "stk_mesh/base/Selector.hpp"
#include "stk_mesh/base/Types.hpp"

namespace stk
{
namespace mesh
{
namespace impl
{

struct RelationEntityToNode
{
    Entity entity;
    Entity node;
    ConnectivityOrdinal ordinal;
};

class ElementTopologyDeletions
{
public:
    ElementTopologyDeletions(stk::mesh::BulkData &bulkData, stk::topology topologyToDelete);
    void find_buckets_to_destroy_and_relations_to_sever();
    const std::vector<RelationEntityToNode> & get_relations_to_sever() const;
    const stk::mesh::BucketVector & get_buckets_to_delete() const;

private:
    stk::mesh::Selector get_all_other_element_topologies_selector(const stk::mesh::MetaData &meta, stk::topology topology);
    void append_upward_relations_to_sever(stk::mesh::Bucket &bucket);
private:
    stk::mesh::BulkData & bulk;
    stk::mesh::Selector topoSelector;
    stk::mesh::Selector selectsOtherElemTopologies;
    stk::mesh::BucketVector bucketsToDelete;
    std::vector<RelationEntityToNode> relationsToDestroy;
};

}
}
}

// Copyright 2002 - 2008, 2010, 2011 National Technology Engineering
// Solutions of Sandia, LLC (NTESS). Under the terms of Contract
// DE-NA0003525 with NTESS, the U.S. Government retains certain rights
// in this software.
//
 // Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are
 // met:
 // 
 //     * Redistributions of source code must retain the above copyright
 //       notice, this list of conditions and the following disclaimer.
 // 
 //     * Redistributions in binary form must reproduce the above
 //       copyright notice, this list of conditions and the following
 //       disclaimer in the documentation and/or other materials provided
 //       with the distribution.
 // 
//     * Neither the name of NTESS nor the names of its contributors
//       may be used to endorse or promote products derived from this
//       software without specific prior written permission.
//
 // THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 // "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 // LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 // A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 // OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 // SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 // LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 // DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 // THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#endif
